void myFitExample(void){
  gROOT->Reset();//Reset session memory
  gROOT->SetStyle("Plain");//Make style plain
  gStyle->SetOptStat(0);//Remove the statistics box from histogram
  char  fString[120];//Character string to hold file name

  sprintf(fString,"./all.root");//Copy filename to character string
  TFile *hFile1 = new TFile(fString);//Open file named ./all.root
  TH1D *hMassKpKmCut1; hFile1->GetObject("hMassKpKmCut1",hMassKpKmCut1);//get histogram 

  hMassKpKmCut1->GetXaxis()->SetRangeUser(0.9,1.2);

  //First do a gaussian fit as a rough idea of the gaussian parameters
  TF1 *f1 = new TF1("f1","gaus",0.0,4.0);//Fit function of type gauss
  hMassKpKmCut1->Fit("f1","R","",1.0,1.04);
  //Get the fit parameters
  double par0 = f1->GetParameter(0);
  double par1 = f1->GetParameter(1);
  double par2 = f1->GetParameter(2);
    
  TF1 *f2 = new TF1("f2","gaus(0)+pol2(3)",0.0,4.0);//Fit function of type gauss+pol2 where
  //the gaussian part starts at parameter 0 and the 2nd order polynomail starts with 
  //parameter 3

  //Seed the fit parameters for the gaussian part with results from prior fit
  f2->SetParameter(0,par0);
  f2->SetParameter(1,par1);
  f2->SetParameter(2,par2);

  //Fit with gauss + pol2
  hMassKpKmCut1->Fit("f2","R","",0.992,1.07);

  //Create our background histogram as a clone of hMassKpKmCut1 and call it hBK
  TH1D *hBK = (TH1D *) hMassKpKmCut1->Clone("hBK");
  //The (TH1D *) part makes the output of the clone function be the right type

  //Save the gaussian parameters of center and sigma
  double center = f2->GetParameter(1);
  double sigma  = f2->GetParameter(2);
  
  //Remove the gaussian part from f2
  f2->SetParameter(0,0.0);

  //Fill the background with f2
  hBK->Eval(f2);
  //Set the line color to red for background and line width = 2
  hBK->SetLineColor(2);
  hBK->SetLineWidth(2);
  //Set the limits on hBK to be the fit range 
  hBK->GetXaxis()->SetRangeUser(0.992,1.07);

  //Draw as smooth curve 
  hBK->Draw("csame");

  //Clone the original histogram and call it hSignal
  TH1D *hSignal = (TH1D *) hMassKpKmCut1->Clone("hSignal");
  //Remove the background from hSignal by multiplying hSignal by 1.0 
  //and adding hBK multiplied by -1.0
  hSignal->Add(hSignal,hBK,1.0,-1.0);
  //Set the limits on hSignal to be +/- three sigma
  hSignal->GetXaxis()->SetRangeUser(center-3*sigma,center+3*sigma);
  //Set the fill style and color (see https://root.cern.ch/doc/master/classTAttFill.html )
  hSignal->SetFillStyle(3001);
  hSignal->SetFillColor(3);
  hSignal->Draw("same");

  //Count the signal
  //NOTE the integral function wants bin numbers and not x-position. 
  //It is a pain, but we do what we do
  int binLow = hSignal->FindBin(center-3*sigma);
  int binHigh = hSignal->FindBin(center+3*sigma);
  //Integrate
  double signalYield = hSignal->Integral(binLow,binHigh);
  cout<<"Yield = "<<signalYield<<" +/- "<<sqrt(signalYield)<<endl;
}
